@@ -8,7 +8,7 @@ use List::Util qw/sum/;
 use Smart::Args;
 use XSLoader;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 XSLoader::load(__PACKAGE__, $VERSION);
 
@@ -202,7 +202,7 @@ Algorithm::LibLinear - A Perl binding for LIBLINEAR, a library for classificatio
 
 Algorithm::LibLinear is an XS module that provides features of LIBLINEAR, a fast C library for classification and regression.
 
-Current version is based on LIBLINEAR 2.1, released on Sep 27, 2015.
+Current version is based on LIBLINEAR 2.11, released on Mar 29, 2017.
 
 =head1 METHODS
 
@@ -296,7 +296,7 @@ Evaluates training parameter using N-fold cross validation method.
 Given data set will be split into N parts. N-1 of them will be used as a training set and the rest 1 part will be used as a test set.
 The evaluation iterates N times using each different part as a test set. Then average accuracy is returned as result.
 
-=head2 find_cost_parameter(data_set => $data_set, max => $max_cost, num_folst => $num_folds [, initial => -1.0] [, update => 0])
+=head2 find_cost_parameter(data_set => $data_set, max => $max_cost, num_folds => $num_folds [, initial => -1.0] [, update => 0])
 
 Find the best cost parameter in terms of cross validation result, between C<initial> and C<max>. If C<initial> parameter is omitted an appropriate value is automatically estimated.
 When true value is specified as C<update> parameter, the instance is updated to use the found cost. This behaviour is disabled by default.
@@ -310,7 +310,7 @@ C<data_set> is same as the C<cross_validation>'s.
 
 =head1 AUTHOR
 
-Koichi SATOH E<lt>sato@seesaa.co.jpE<gt>
+Koichi SATOH E<lt>sekia@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -328,7 +328,7 @@ L<Algorithm::SVM> - A Perl binding to LIBSVM.
 
 =head2 Algorithm::LibLinear
 
-Copyright (c) 2013-2015 Koichi SATOH. All rights reserved.
+Copyright (c) 2013-2017 Koichi SATOH. All rights reserved.
 
 The MIT License (MIT)
 
