@@ -15,17 +15,18 @@ public:
 class TRON
 {
 public:
-	TRON(const function *fun_obj, double eps = 0.1, int max_iter = 1000);
+	TRON(const function *fun_obj, double eps = 0.1, double eps_cg = 0.1, int max_iter = 1000);
 	~TRON();
 
 	void tron(double *w);
 	void set_print_string(void (*i_print) (const char *buf));
 
 private:
-	int trcg(double delta, double *g, double *s, double *r);
+	int trcg(double delta, double *g, double *s, double *r, bool *reach_boundary);
 	double norm_inf(int n, double *x);
 
 	double eps;
+	double eps_cg;
 	int max_iter;
 	function *fun_obj;
 	void info(const char *fmt,...);
